---
sidebar_position: 2
description: DePIN Board by Category
---

# DePIN Board

The DePIN Board provides an organized overview of various DePIN projects, categorized by their primary focus areas, such as compute, storage, wireless, energy, sensor, and mobility networks, among others.

The purpose of this board is to provide educational and informational content only. If you have any feedback, please let us know by writing an [issue on our Gitea instance](https://git.ourworld.tf/tfgrid/info_docs_depin).

> To learn more about a specific project, click on the project name in the leftmost column.

## Compute Networks

| Project Name       | Infrastructure Ownership       | Hardware Requirements          | Software Stack               | Open Source | Docker Support | ThreeFold Grid Compatible | Notes                                                                 |
|--------------------|--------------------------------|--------------------------------|------------------------------|-------------|----------------|---------------------------|-----------------------------------------------------------------------|
| [Render Network](./depin_specs/compute_networks/render_network.md) | Hybrid (Owned + Decentralized) | GPUs                           | Ethereum, IPFS               | Yes         | Yes            | Yes                       | Focused on GPU rendering for 3D and AI workloads.                    |
| [Akash Network](./depin_specs/compute_networks/akash_network.md)  | Fully Decentralized            | Standard servers               | Kubernetes, Cosmos SDK       | Yes         | Yes            | Yes                       | Decentralized cloud computing with competitive pricing.              |
| [Golem Network](./depin_specs/compute_networks/golem_network.md)  | Fully Decentralized            | GPUs, standard servers         | Ethereum, Docker             | Yes         | Yes            | Yes                       | Decentralized compute power for general-purpose tasks.               |
| [iExec](./depin_specs/compute_networks/iexec.md)          | Fully Decentralized            | GPUs, standard servers         | Ethereum, Docker             | Yes         | Yes            | Yes                       | Decentralized cloud computing for dApps.                             |
| [Flux](./depin_specs/compute_networks/flux.md)           | Fully Decentralized            | Standard servers, GPUs         | Custom blockchain, Docker    | Yes         | Yes            | Yes                       | Decentralized cloud infrastructure with strong community support.    |
| [Internet Computer (ICP)](./depin_specs/compute_networks/internet_computer.md) | Fully Decentralized            | Standard servers               | Custom blockchain, Canisters | Yes         | No             | No                        | Decentralized cloud computing platform for hosting Web3 applications.|

---

## Storage Networks

| Project Name       | Infrastructure Ownership       | Hardware Requirements          | Software Stack               | Open Source | Docker Support | ThreeFold Grid Compatible | Notes                                                                 |
|--------------------|--------------------------------|--------------------------------|------------------------------|-------------|----------------|---------------------------|-----------------------------------------------------------------------|
| [Filecoin](./depin_specs/storage_networks/filecoin.md)       | Fully Decentralized            | Storage servers                | IPFS, Custom blockchain      | Yes         | Yes            | Yes                       | Decentralized storage with strong incentives for data storage.       |
| [Arweave](./depin_specs/storage_networks/arweave.md)        | Fully Decentralized            | Storage servers                | Custom blockchain, IPFS      | Yes         | Yes            | Yes                       | Permanent, decentralized data storage.                               |
| [Storj](./depin_specs/storage_networks/storj.md)          | Fully Decentralized            | Storage servers                | Ethereum, IPFS               | Yes         | Yes            | Yes                       | Decentralized cloud storage with S3 compatibility.                   |
| [Sia](./depin_specs/storage_networks/sia.md)            | Fully Decentralized            | Storage servers                | Custom blockchain            | Yes         | Yes            | Yes                       | Decentralized storage platform with a focus on affordability.        |
| [Crust Network](./depin_specs/storage_networks/crust_network.md)  | Fully Decentralized            | Storage servers                | Substrate, IPFS              | Yes         | Yes            | Yes                       | Decentralized storage and hosting for Web3 applications.             |

---

## Wireless Networks

| Project Name       | Infrastructure Ownership       | Hardware Requirements          | Software Stack               | Open Source | Docker Support | ThreeFold Grid Compatible | Notes                                                                 |
|--------------------|--------------------------------|--------------------------------|------------------------------|-------------|----------------|---------------------------|-----------------------------------------------------------------------|
| [Helium](./depin_specs/wireless_networks/helium.md)         | Fully Decentralized            | IoT hotspots                   | Custom blockchain, LoRaWAN   | Partial     | No             | No                        | Decentralized wireless IoT network with global coverage.             |
| [Pollum](./depin_specs/wireless_networks/pollum.md)         | Fully Decentralized            | 5G hotspots                   | Custom blockchain            | Partial     | No             | No                        | Helium's 5G network for mobile connectivity.                         |
| [Nodle](./depin_specs/wireless_networks/nodle.md)          | Fully Decentralized            | IoT devices                   | Custom blockchain, Bluetooth | Yes         | No             | Yes                       | IoT connectivity via Bluetooth.                                      |
| [World Mobile](./depin_specs/wireless_networks/world_mobile.md)   | Hybrid (Owned + Decentralized) | IoT devices, mobile hardware   | Cardano, Custom blockchain   | Partial     | No             | No                        | Decentralized mobile network with a focus on underserved regions.    |
| [Althea](./depin_specs/wireless_networks/althea.md)         | Fully Decentralized            | Routers, IoT devices           | Ethereum, Custom blockchain  | Yes         | No             | Yes                       | Decentralized internet access with pay-as-you-go models.             |

---

## Energy Networks

| Project Name       | Infrastructure Ownership       | Hardware Requirements          | Software Stack               | Open Source | Docker Support | ThreeFold Grid Compatible | Notes                                                                 |
|--------------------|--------------------------------|--------------------------------|------------------------------|-------------|----------------|---------------------------|-----------------------------------------------------------------------|
| [Power Ledger](./depin_specs/energy_networks/power_ledger.md)   | Hybrid (Owned + Decentralized) | Smart meters, energy hardware  | Ethereum, Custom blockchain  | Partial     | No             | Yes                       | Peer-to-peer energy trading platform.                                |
| [Energy Web](./depin_specs/energy_networks/energy_web.md)     | Hybrid (Owned + Decentralized) | Smart meters, energy hardware  | Ethereum, Custom blockchain  | Partial     | No             | Yes                       | Decentralized energy grid solutions.                                 |
| [Grid+](./depin_specs/energy_networks/grid_plus.md)          | Hybrid (Owned + Decentralized) | Smart meters, energy hardware  | Ethereum, Custom blockchain  | Partial     | No             | Yes                       | Decentralized energy management.                                     |
| [SunContract](./depin_specs/energy_networks/suncontract.md)    | Fully Decentralized            | Smart meters, energy hardware  | Ethereum, Custom blockchain  | Yes         | No             | Yes                       | Peer-to-peer energy trading with a focus on green energy.            |

---

## Sensor Networks

| Project Name       | Infrastructure Ownership       | Hardware Requirements          | Software Stack               | Open Source | Docker Support | ThreeFold Grid Compatible | Notes                                                                 |
|--------------------|--------------------------------|--------------------------------|------------------------------|-------------|----------------|---------------------------|-----------------------------------------------------------------------|
| [IoTeX](./depin_specs/sensor_networks/iotex.md)          | Fully Decentralized            | IoT devices, Raspberry Pi      | Ethereum, Custom blockchain  | Yes         | Yes            | Yes                       | Decentralized IoT infrastructure with privacy features.              |
| [Hivemapper](./depin_specs/sensor_networks/hivemapper.md)     | Fully Decentralized            | Dashcams, IoT devices          | Solana, IPFS                 | Partial     | No             | Yes                       | Decentralized mapping network with strong incentives for contributors.|
| [WeatherXM](./depin_specs/sensor_networks/weatherxm.md)      | Fully Decentralized            | Weather stations               | Ethereum, Custom blockchain  | Partial     | No             | Yes                       | Decentralized weather data collection.                               |
| [DIMO](./depin_specs/sensor_networks/dimo.md)           | Fully Decentralized            | IoT devices, vehicles          | Ethereum, IPFS               | Yes         | Yes            | Yes                       | Decentralized IoT for vehicle data and mobility.                     |

---

## Mobility Networks

| Project Name       | Infrastructure Ownership       | Hardware Requirements          | Software Stack               | Open Source | Docker Support | ThreeFold Grid Compatible | Notes                                                                 |
|--------------------|--------------------------------|--------------------------------|------------------------------|-------------|----------------|---------------------------|-----------------------------------------------------------------------|
| [Carv](./depin_specs/mobility_networks/carv.md)           | Fully Decentralized            | IoT devices, vehicles          | Ethereum, IPFS               | Yes         | Yes            | Yes                       | Decentralized vehicle data sharing.                                  |
| [Drife](./depin_specs/mobility_networks/drife.md)          | Fully Decentralized            | Mobile devices, vehicles       | Ethereum, Custom blockchain  | Yes         | No             | Yes                       | Decentralized ride-hailing platform.                                 |
| [Arcade City](./depin_specs/mobility_networks/arcade_city.md)    | Fully Decentralized            | Mobile devices, vehicles       | Ethereum, Custom blockchain  | Yes         | No             | Yes                       | Decentralized ride-sharing platform.                                 |

---

## Miscellaneous DePIN Projects

| Project Name       | Infrastructure Ownership       | Hardware Requirements          | Software Stack               | Open Source | Docker Support | ThreeFold Grid Compatible | Notes                                                                 |
|--------------------|--------------------------------|--------------------------------|------------------------------|-------------|----------------|---------------------------|-----------------------------------------------------------------------|
| [Livepeer](./depin_specs/miscellaneous_depin_projects/livepeer.md)       | Fully Decentralized            | GPUs                           | Ethereum, IPFS               | Yes         | Yes            | Yes                       | Decentralized video streaming network.                               |
| [Theta Network](./depin_specs/miscellaneous_depin_projects/theta_network.md)  | Hybrid (Owned + Decentralized) | Consumer-grade hardware        | Ethereum, IPFS               | Partial     | Yes            | Yes                       | Decentralized video delivery with strong partnerships.               |
| [Audius](./depin_specs/miscellaneous_depin_projects/audius.md)         | Hybrid (Owned + Decentralized) | Standard servers               | Ethereum, IPFS               | Partial     | Yes            | Yes                       | Decentralized music streaming platform.                              |
| [Arbol](./depin_specs/miscellaneous_depin_projects/arbol.md)          | Fully Decentralized            | IoT devices, weather stations  | Ethereum, Custom blockchain  | Partial     | No             | Yes                       | Decentralized weather data for insurance and agriculture.            |
| [Silent Notary](./depin_specs/miscellaneous_depin_projects/silent_notary.md)  | Fully Decentralized            | Standard servers               | Ethereum, Custom blockchain  | Yes         | Yes            | Yes                       | Decentralized data notarization for legal and compliance.            |
| [Morpheus](./depin_specs/miscellaneous_depin_projects/morpheus.md) | Fully Decentralized            | Standard servers               | Custom blockchain, Privacy protocols | Yes         | Yes            | Yes                       | Privacy-preserving infrastructure for Web3 applications.             |

---

## Emerging DePIN Projects

| Project Name       | Infrastructure Ownership       | Hardware Requirements          | Software Stack               | Open Source | Docker Support | ThreeFold Grid Compatible | Notes                                                                 |
|--------------------|--------------------------------|--------------------------------|------------------------------|-------------|----------------|---------------------------|-----------------------------------------------------------------------|
| [Aethir](./depin_specs/emerging_depin_projects/aethir.md)         | Fully Decentralized            | GPUs                           | Ethereum, IPFS               | Yes         | Yes            | Yes                       | Decentralized GPU cloud for AI and rendering.                        |
| [Meson Network](./depin_specs/emerging_depin_projects/meson_network.md)  | Fully Decentralized            | Standard servers               | Ethereum, IPFS               | Yes         | Yes            | Yes                       | Decentralized bandwidth sharing for Web3 applications.               |
| [KYVE](./depin_specs/emerging_depin_projects/kyve.md)           | Fully Decentralized            | Standard servers               | Cosmos SDK, IPFS             | Yes         | Yes            | Yes                       | Decentralized data validation for blockchain history.                |
| [Spheron Network](./depin_specs/emerging_depin_projects/spheron_network.md)| Fully Decentralized            | Standard servers               | IPFS, Custom blockchain      | Yes         | Yes            | Yes                       | Decentralized web hosting for Web3 applications.                     |
| [Wicrypt](./depin_specs/emerging_depin_projects/wicrypt.md)        | Fully Decentralized            | Routers, IoT devices           | Ethereum, Custom blockchain  | Yes         | No             | Yes                       | Decentralized WiFi sharing for underserved regions.                  |

---

## Experimental and Niche DePIN Projects

| Project Name       | Infrastructure Ownership       | Hardware Requirements          | Software Stack               | Open Source | Docker Support | ThreeFold Grid Compatible | Notes                                                                 |
|--------------------|--------------------------------|--------------------------------|------------------------------|-------------|----------------|---------------------------|-----------------------------------------------------------------------|
| [SpaceChain](./depin_specs/experimental_and_niche_depin_projects/spacechain.md)     | Hybrid (Owned + Decentralized) | Satellites, ground stations    | Ethereum, Custom blockchain  | Partial     | No             | No                        | Decentralized satellite infrastructure.                              |
| [SmartMesh](./depin_specs/experimental_and_niche_depin_projects/smartmesh.md)      | Fully Decentralized            | IoT devices, mobile hardware   | Ethereum, Custom blockchain  | Yes         | No             | Yes                       | Decentralized mesh networking for IoT.                               |
| [Elastos](./depin_specs/experimental_and_niche_depin_projects/elastos.md)        | Fully Decentralized            | Standard servers               | Custom blockchain, IPFS      | Yes         | Yes            | Yes                       | Decentralized internet OS for Web3 applications.                     |
| [Autonomys](./depin_specs/experimental_and_niche_depin_projects/autonomys.md)       | Fully Decentralized            | Standard servers               | Custom blockchain, IPFS      | Yes         | Yes            | Yes                       | Decentralized storage for blockchain history.                        |